==> copilot-24.5.5-sources.jar: com/vaadin/copilot/plugins/devsetup/DevSetupHandler.java <==
package com.vaadin.copilot.plugins.devsetup;

import com.vaadin.base.devserver.DevToolsInterface;
import com.vaadin.copilot.CopilotCommand;
import com.vaadin.copilot.ide.CopilotIDEPlugin;
import com.vaadin.copilot.plugins.info.JdkInfo;

import elemental.json.Json;
import elemental.json.JsonObject;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/** Handler for development environment setup. */
public class DevSetupHandler implements CopilotCommand {
    private final CopilotIDEPlugin idePlugin;
    private final ObjectMapper objectMapper;

    public DevSetupHandler(CopilotIDEPlugin idePlugin) {
        this.idePlugin = idePlugin;
        this.objectMapper = new ObjectMapper();
        objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
    }

    @Override
    public boolean handleMessage(String command, JsonObject data, DevToolsInterface devToolsInterface) {
        if ("get-dev-setup-info".equals(command)) {
            var responseData = Json.createObject();

            JdkInfo jdkInfo = JdkInfo.get();
            try {
                DevSetupInfo devSetupInfo = new DevSetupInfo(jdkInfo, idePlugin.getPluginInfo());
                responseData.put("content", objectMapper.writeValueAsString(devSetupInfo));
                devToolsInterface.send("copilot-get-dev-setup-info-response", responseData);
            } catch (Exception e) {
                getLogger().error(e.getMessage(), e);
            }

            return true;
        }
        return false;
    }

    protected Logger getLogger() {
        return LoggerFactory.getLogger(getClass());
    }
}

==> copilot-24.7.3-sources.jar: com/vaadin/copilot/plugins/devsetup/DevSetupHandler.java <==
package com.vaadin.copilot.plugins.devsetup;

import com.vaadin.base.devserver.DevToolsInterface;
import com.vaadin.copilot.CopilotCommand;
import com.vaadin.copilot.ide.CopilotIDEPlugin;
import com.vaadin.copilot.plugins.info.JdkInfo;

import elemental.json.Json;
import elemental.json.JsonObject;

import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/** Handler for development environment setup. */
public class DevSetupHandler extends CopilotCommand {
    private final CopilotIDEPlugin idePlugin;
    private final ObjectMapper objectMapper;

    public DevSetupHandler(CopilotIDEPlugin idePlugin) {
        this.idePlugin = idePlugin;
        this.objectMapper = new ObjectMapper();
        objectMapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
    }

    @Override
    public boolean handleMessage(String command, JsonObject data, DevToolsInterface devToolsInterface) {
        if ("get-dev-setup-info".equals(command)) {
            var responseData = Json.createObject();

            JdkInfo jdkInfo = JdkInfo.get();
            try {
                DevSetupInfo devSetupInfo = new DevSetupInfo(jdkInfo, idePlugin.getPluginInfo());
                responseData.put("content", objectMapper.writeValueAsString(devSetupInfo));
                devToolsInterface.send("copilot-get-dev-setup-info-response", responseData);
            } catch (Exception e) {
                getLogger().error(e.getMessage(), e);
            }

            return true;
        }
        return false;
    }

    protected Logger getLogger() {
        return LoggerFactory.getLogger(getClass());
    }
}
